use rodio::{Decoder, Source, OutputStream};
use std::error::Error;
use std::fs::File;
use std::io::BufReader;
use std::path::PathBuf;

#[derive(Debug, Clone)]
pub struct Alert {
    path: PathBuf,
}

impl Alert {
    pub fn new(path: PathBuf) -> Self {
        Self { path }
    }

    pub fn load(&mut self, path: PathBuf) {
        self.path = path;
    }

    pub fn play(&self) -> Result<(), Box<dyn Error>> {
        let (_, handle) = OutputStream::try_default()?;
        let file = File::open(&self.path)?;
        let source = Decoder::new(BufReader::new(file))?;

        handle.play_raw(source.convert_samples()).unwrap(); // use ?, blocked: https://github.com/RustAudio/rodio/pull/329
        Ok(())
    }
}
